@@ -87,7 +87,7 @@ QString KNSResource::longDescription()
     ret.remove(QRegularExpression(QStringLiteral("\\[\\/?[a-z]*\\]")));
     // Find anything that looks like a link (but which also is not some html
     // tag value or another already) and make it a link
-    static const QRegularExpression urlRegExp(QStringLiteral("(^|\\s)([-a-zA-Z0-9@:%_\\+.~#?&//=]{2,256}\\.[a-z]{2,4}\\b(\\/[-a-zA-Z0-9@:;%_\\+.~#?&//=]*)?)"), QRegularExpression::CaseInsensitiveOption);
+    static const QRegularExpression urlRegExp(QStringLiteral("(^|\\s)(http[-a-zA-Z0-9@:%_\\+.~#?&//=]{2,256}\\.[a-z]{2,4}\\b(\\/[-a-zA-Z0-9@:;%_\\+.~#?&//=]*)?)"), QRegularExpression::CaseInsensitiveOption);
     ret.replace(urlRegExp, QStringLiteral("<a href=\"\\2\">\\2</a>"));
     return ret;
 }
@@ -140,12 +140,13 @@ int KNSResource::size()
 
 QString KNSResource::installedVersion() const
 {
-    return m_entry.version();
+    return !m_entry.version().isEmpty() ? m_entry.version() : m_entry.releaseDate().toString();
 }
 
 QString KNSResource::availableVersion() const
 {
     return !m_entry.updateVersion().isEmpty() ? m_entry.updateVersion()
+         : !m_entry.updateReleaseDate().isNull() ? m_entry.updateReleaseDate().toString()
          : !m_entry.version().isEmpty() ? m_entry.version()
          : releaseDate().toString();
 }
@@ -195,37 +196,24 @@ QStringList KNSResource::extends() const
     return knsBackend()->extends();
 }
 
-QStringList KNSResource::executables() const
-{
-    if (knsBackend()->engine()->hasAdoptionCommand())
-        return {knsBackend()->engine()->adoptionCommand(m_entry)};
-    else
-        return {};
-}
-
 QUrl KNSResource::url() const
 {
     return QUrl(QStringLiteral("kns://")+knsBackend()->name() + QLatin1Char('/') + QUrl(m_entry.providerId()).host() + QLatin1Char('/') + m_entry.uniqueId());
 }
 
+bool KNSResource::canExecute() const
+{
+    return knsBackend()->engine()->hasAdoptionCommand();
+}
+
 void KNSResource::invokeApplication() const
 {
-    QStringList exes = executables();
-    if(!exes.isEmpty()) {
-        const QString exe = exes.constFirst();
-        auto args = KShell::splitArgs(exe);
-        QProcess::startDetached(args.takeFirst(), args);
-    } else {
-        qWarning() << "cannot execute" << packageName();
-    }
+    knsBackend()->engine()->adoptEntry(m_entry);
 }
 
 QString KNSResource::executeLabel() const
 {
-    if(knsBackend()->hasApplications()) {
-        return i18n("Launch");
-    }
-    return i18n("Use");
+    return knsBackend()->engine()->useLabel();
 }
 
 QDate KNSResource::releaseDate() const
@@ -255,13 +243,13 @@ Rating * KNSResource::ratingInstance()
         const int noc = m_entry.numberOfComments();
         const int rating = m_entry.rating();
         Q_ASSERT(rating <= 100);
-        return new Rating(
+        m_rating.reset(new Rating(
             packageName(),
             noc,
             rating / 10
-        );
+        ));
     }
-    return m_rating;
+    return m_rating.data();
 }
 
 QString KNSResource::author() const
