@@ -9,7 +9,6 @@
 #include "PackageKitBackend.h"
 #include "PackageKitMessages.h"
 #include <KLocalizedString>
-#include <PackageKit/Details>
 #include <PackageKit/Daemon>
 #include <QJsonArray>
 #include <QDebug>
@@ -55,16 +54,16 @@ QString PackageKitResource::availablePackageId() const
     if (!pkgid.isEmpty())
         return pkgid;
 
-    QMap<PackageKit::Transaction::Info, QStringList>::const_iterator it = m_packages.constFind(PackageKit::Transaction::InfoAvailable);
+    const auto it = m_packages.constFind(PackageKit::Transaction::InfoAvailable);
     if (it != m_packages.constEnd())
-        return it->last();
+        return it->first();
     return installedPackageId();
 }
 
 QString PackageKitResource::installedPackageId() const
 {
     const auto installed = m_packages[PackageKit::Transaction::InfoInstalled];
-    return installed.isEmpty() ? QString() : installed.last();
+    return installed.isEmpty() ? QString() : installed.first();
 }
 
 QString PackageKitResource::comment()
@@ -148,12 +147,14 @@ void PackageKitResource::addPackageId(PackageKit::Transaction::Info info, const
 {
     auto oldState = state();
     if (arch)
-        m_packages[info].append(packageId);
+        m_packages[info].archPkgIds.append(packageId);
     else
-        m_packages[info].prepend(packageId);
+        m_packages[info].nonarchPkgIds.append(packageId);
 
     if (oldState != state())
         emit stateChanged();
+
+    Q_EMIT versionsChanged();
 }
 
 QStringList PackageKitResource::categories()
@@ -197,6 +198,7 @@ void PackageKitResource::setDetails(const PackageKit::Details & details)
 
     if (m_details != details) {
         const auto oldState = state();
+        const auto oldSize = m_details.size();
         m_details = details;
 
         if (oldState != state())
@@ -204,6 +206,10 @@ void PackageKitResource::setDetails(const PackageKit::Details & details)
 
         if (!backend()->isFetching())
             Q_EMIT backend()->resourcesChanged(this, {"size", "homepage", "license"});
+
+        if (oldSize != uint(size())) {
+            Q_EMIT sizeChanged();
+        }
     }
 }
 
